@@ -8,32 +8,25 @@
 
 ## Processes character input, presumably States, and when empty
 ## character vector, provide all the States as a default value.
-.processRegionParam <- function(s)
+.process_region_params <- function(s, ...)
 {
   stopifnot(is.character(s))
+  len <- length(s)
   
-  if (length(s) == 0L)
+  if (len == 0L)
     return(states(all = TRUE))
   
-  isregion <- all(is_state(s)) || all(is_lga(s))
-  
-  if (!isregion) {
+  if (!(all(is_state(s)) || all(is_lga(s)))) {
     
-    if (length(s) > 1L) {
-      stop(sprintf(
-        "One or more elements of '%s' is not a Nigerian region",
-        deparse(substitute(s))
-      ),
-      call. = FALSE)
+    if (len > 1L) {
+      cli::cli_abort(
+        "One or more elements of '{deparse(substitute(s))}' is not a Nigerian region",
+        ...)
     }
-    else if (s != .ngName()) {
-      stop(
-        sprintf(
-          "Single inputs for '%s' only support the value '%s'",
-          deparse(substitute(s)),
-          .ngName()
-        ),
-        call. = FALSE
+    else if (isFALSE(identical(s, country_name()))) {
+      cli::cli_abort(
+          "Single inputs for '{deparse(substitute(s))}' only support the value '{country_name()}'",
+          ...
       )
     }
   }
@@ -44,20 +37,17 @@
 
 
 
-# Makes sure that all the elements required for making
-# a choropleth map are available. These are:
+# Makes sure that the elements required for making a choropleth map are available. 
+# These are:
 # - A data frame with a value and region column identified
 # - A 2-column data frame with one column of regions
 # - A region and value as separate vectors
-# 
-
-# - 
-
+#
 #' @importFrom rlang as_name
 #' @importFrom rlang enexpr
 #' @importFrom rlang is_null
 #' @importFrom rlang is_symbol
-.validateChoroplethParams <- function(val = NULL, region = NULL, data = NULL)
+.validate_choropleth_params <- function(val = NULL, region = NULL, data = NULL)
 {   # TODO: Add some verbosity.
   val <- enexpr(val)
   
@@ -68,7 +58,7 @@
     if (is.null(val) || is.null(region))
       return(FALSE)
     
-    if (!.allAreRegions(region) && !is.null(val))
+    if (!.all_are_regions(region) && !is.null(val))
       return(FALSE)
     # At this point, we have two valid vectors only
   }
@@ -76,7 +66,7 @@
   data.has.regions <- FALSE
   
   if (is.data.frame(data)) {
-    index <- .regionColumnIndex(data)
+    index <- .region_column_index(data)
     data.has.regions <- as.logical(index)
     
     # Once identified, the regions in the data frame are
@@ -88,10 +78,8 @@
       assign(deparse(substitute(region)), r, envir = parent.frame())
     }
   }
-  else if (!is.null(data)) {
-    warning(sprintf("'%s' is invalid for choropleths but was ignored",
-                    .arg_str(data)))
-  }
+  else if (!is.null(data))
+    cli::cli_warn("'{.arg_str(data)}' is invalid for choropleths but was ignored")
   
   ## If 'region' is NULL, it must be found automatically in 'data'
   if (is.null(region)) {
@@ -102,7 +90,7 @@
     region <- character()
   }
   
-  if (!.allAreRegions(region))
+  if (!.all_are_regions(region))
     return(FALSE)
   
   ## If 'val' is null, it must exist in 'data', but can only be
@@ -116,7 +104,7 @@
     if (ncol(data) > 2L)
       return(FALSE)
     
-    if (isFALSE(.allAreRegions(region)) && isFALSE(data.has.regions))
+    if (isFALSE(.all_are_regions(region)) && isFALSE(data.has.regions))
       return(FALSE)
   }
   
@@ -124,11 +112,9 @@
     
     if (is.data.frame(data)) {
       
-      if (is_symbol(val) &&
-          isFALSE(as_name(val) %in% names(data))) {
-        stop(sprintf("The column '%s' does not exist in '%s'",
-                     .arg_str(val), .arg_str(data)),
-             call. = FALSE)
+      if (is_symbol(val) && isFALSE(as_name(val) %in% names(data))) {
+        cli::cli_abort("The column '{(.arg_str(val))}'
+                       does not exist in '{(.arg_str(data))}'")
       }
     }
   }
@@ -141,12 +127,12 @@
 
 
 ## S3 Class and methods for internal use:
-.getMapData <- function(x)
-  UseMethod(".getMapData")
+.get_map_data <- function(x)
+  UseMethod(".get_map_data")
 
 
 #' @import mapdata
-.getMapData.default <- function(x) 
+.get_map_data.default <- function(x) 
 {
   if (is.factor(x))
     x <- as.character(x)
@@ -156,46 +142,46 @@
   if (identical(x, 'Nigeria'))
     return("mapdata::worldHires")
   
-  if ((length(x) == 1L && (x %in% .synonymRegions()))
-      || all(is_state(x)))
-    return(.getMapData(states(x)))
+  if ((length(x) == 1L && (x %in% .lgas_like_states())) || 
+      all(is_state(x)))
+    return(.get_map_data(states(x)))
   
-  .getMapData(lgas(x))
+  .get_map_data(lgas(x))
 }
 
 
-.getMapData.lgas <- function(x)
+.get_map_data.lgas <- function(x)
 {
-  spo <- .fixNasState(shp.lga[['spatialObject']], "STATE")
+  spo <- .fix_nas_state(shp.lga[['spatialObject']], "STATE")
   st.nm <- attr(x, 'State')
   
   if (length(st.nm) > 1L)
-    stop("LGA-level maps for adjoining States are not yet supported")
+    cli::cli_abort("LGA-level maps for adjoining States are not yet supported")
   
   lgaObj <- if (!is.null(st.nm)) {
     
-    if (st.nm %in% .fctOptions())  # peculiar to this scope
+    if (st.nm %in% .fct_options())  # peculiar to this scope
       st.nm <- "Abuja"
-    spo[grep(.regexSubsetRegions(st.nm), spo@data$STATE), ]
+    spo[grep(.regex_subset_regions(st.nm), spo@data$STATE), ]
   }
   else
-    spo[grep(.regexSubsetRegions(x), spo@data$LGA), ]
+    spo[grep(.regex_subset_regions(x), spo@data$LGA), ]
   
-  .createBaseMapsObject(lgaObj, shp.lga)
+  .create_base_maps_object(lgaObj, shp.lga)
 }
 
 
 
 
 
-.getMapData.states <- function(x)
+.get_map_data.states <- function(x)
 {
-  spo <- .fixNasState(shp.state[['spatialObject']], "admin1Name")
+  spo <- .fix_nas_state(shp.state[['spatialObject']], "admin1Name")
   
   stateObj <- 
-    spo[grep(.regexSubsetRegions(x), spo@data$admin1Name), ]
+    spo[grep(.regex_subset_regions(x), spo@data$admin1Name), ]
   
-  .createBaseMapsObject(stateObj, shp.state)
+  .create_base_maps_object(stateObj, shp.state)
 }
 
 
@@ -203,18 +189,18 @@
 
 
 #' @importFrom maps SpatialPolygons2map
-.createBaseMapsObject <- function(obj, shapefileObj) {
+.create_base_maps_object <- function(obj, shapefileObj) {
   SpatialPolygons2map(obj, namefield = shapefileObj[['namefield']])
 }
 
 
-.fixNasState <- function(obj, namefield)
+.fix_nas_state <- function(obj, namefield)
 {
-  .fixBadShpfileRegion(obj, namefield, "Nassarawa", "Nasarawa")
+  .fix_bad_shpfile_region(obj, namefield, "Nassarawa", "Nasarawa")
 }
 
 
-.fixBadShpfileRegion <- function(obj, namefield, old, new) 
+.fix_bad_shpfile_region <- function(obj, namefield, old, new) 
 {
   # TODO: Consider using reference semantics for 'obj'
   stopifnot({
@@ -223,31 +209,25 @@
     is.character(old)
     is.character(new)
   })
+  
   obj@data[[namefield]] <- sub(old, new, obj@data[[namefield]])
   obj
 }
 
 
-# .fixBadNames <- function(map)
-# {
-#   map$names[map$names == "Nasarawa"] <- "Nassarawa"
-#   map
-# }
-
-
 
 
 # States that are also the names of LGAs
-.LgaLikeStates <-
-  function()
-    c("Bauchi",
-      "Ebonyi",
-      "Ekiti",
-      "Gombe",
-      "Katsina",
-      "Kogi",
-      "Nasarawa",
-      "Oyo")
+.lgas_like_states <- function()
+{
+  c("Bauchi",
+    "Ebonyi",
+    "Ekiti",
+    "Gombe",
+    "Katsina",
+    "Kogi",
+    "Nasarawa")
+}
 
 
 
@@ -256,11 +236,18 @@
 .getShapefileDir <- function(region)
   UseMethod(".getShapefileDir")
 
+
+
+
 .getShapefileDir.states <- function(region)
 {
   'ng_admin'
 }
 
+
+
+
+
 .getShapefileDir.lgas <- function(region)
 {
   'nigeria-lgas'
@@ -269,23 +256,18 @@
 
 
 
-
-
-
-
-
-# For possible export later
-.shpLayer <- function(level) {
-  
-  if (level == 'state')
-    "nga_admbnda_adm1_osgof_20161215"
-  else if (level == 'lga')
-    "new_lga_nigeria_2003"
-  # "NIGERIA_LGA"
-  # "Nigeria_census_2006_WGS84"
-  else
-    stop("An appropriate layer is not avaiable")
-}
+# # For possible export later
+# .shpLayer <- function(level) {
+#   
+#   if (level == 'state')
+#     "nga_admbnda_adm1_osgof_20161215"
+#   else if (level == 'lga')
+#     "new_lga_nigeria_2003"
+#   # "NIGERIA_LGA"
+#   # "Nigeria_census_2006_WGS84"
+#   else
+#     stop("An appropriate layer is not avaiable")
+# }
 
 
 
@@ -296,7 +278,7 @@
 ## used for drawing a choropleth map
 #' @importFrom rlang abort
 #' @importFrom rlang warn
-.regionColumnIndex <- function(dt, s = NULL)
+.region_column_index <- function(dt, s = NULL)
 {
   stopifnot(is.data.frame(dt))
   
@@ -309,13 +291,13 @@
     ret <- FALSE
     
     if (is.character(x)) {
-      ret <- .allAreRegions(x)
+      ret <- .all_are_regions(x)
       
       # TODO: apply a ?restart here when there are misspelt States
       # and try to fix them automatically and then apply the function
       # one more time. Do so verbosely.
-      if (!ret && .someAreRegions(x))
-        warning("Misspelt region(s) in the dataset", call. = FALSE)
+      if (!ret && .some_are_regions(x))
+        cli::cli_warn("Misspelt region(s) in the dataset")
     }
     ret
   }
@@ -326,13 +308,10 @@
     s <- states()
   
   if (!sum(n))
-    stop(sprintf("No column with elements in '%s'.", 
-                 deparse(substitute(dt))),
-         call. = FALSE)
+    cli::cli_abort("No column with elements in '{deparse(substitute(dt))}'.")
   
   if (sum(n) > 1)
-    warning("Multiple columns have regions, so the first was used",
-            call. = FALSE)
+    cli::cli_warn("Multiple columns have regions, so the first was used")
   
   which(n)[1]
 }
@@ -340,20 +319,17 @@
 
 
 
-
-
-
-
-#' @importFrom rlang abort
-.prepChoroplethOpts <-
+.prep_choropleth_opts <-
   function(map, opts, col = NULL, ...)
   {
     # TODO: Set limits for variables and brk
     # TODO: Accept numeric input for col
     stopifnot(inherits(map, 'map'))
     
-    if(!.assertListElements(opts))
-      abort("One or more inputs for generating choropleth options are invalid")
+    if(!.assert_list_elements(opts))
+      cli::cli_abort(
+        "One or more inputs for generating choropleth options are invalid"
+      )
     
     brks <- opts$breaks
     
@@ -364,9 +340,9 @@
         stringsAsFactors = FALSE
       )
     
-    df$cat <- .createCategorized(df$value, brks)
+    df$cat <- .create_categorized(df$value, brks)
     cats <- levels(df$cat)
-    colrange <- .processColouring(col, length(cats))
+    colrange <- .process_colouring(col, length(cats))
     
     # At this point, our value of 
     # interest is definitely a factor
@@ -385,7 +361,7 @@
     
     new.ind <- order(as.character(df$region), mapregions)
     ord.df <- df[new.ind, ]    # This is why a data frame was made
-    colors <- .reassignColours(map$names, ord.df$region, ord.df$color, ...)
+    colors <- .reassign_colours(map$names, ord.df$region, ord.df$color, ...)
     
     list(colors = colors,
          scheme = colrange,
@@ -397,26 +373,19 @@
 
 
 
-#' @importFrom magrittr %>%
-.assertListElements <- function(x) {
+.assert_list_elements <- function(x) {
   stopifnot(c('region', 'value', 'breaks') %in% names(x))
   
-  region.valid <- .allAreRegions(x$region)
-  
-  value.valid <- 
-    x$value %>% 
-    {
-      is.numeric(.) || is.factor(.) || is.character(.)
-    }
+  region.valid <- .all_are_regions(x$region)
+  v <- x$value
+  value.valid <- is.numeric(v) || is.factor(v) || is.character(v)
+  c <- x$categories
   
   cat.valid <-
-    x$categories %>%
-    {
-      if (!is.null(.))
-        is.character(.) || is.factor(.)
-      else
-        TRUE
-    }
+    if (!is.null(c))
+      is.character(c) || is.factor(c)
+  else
+    TRUE
   
   all(region.valid, value.valid, cat.valid)
 }
@@ -430,9 +399,8 @@
 
 # Creates a  categorised variable from its inputs if not already a factor
 # and is to be used in generating choropleth maps
-#' @importFrom rlang abort
-#' @importFrom rlang is_scalar_integer
-.createCategorized <- function(val, brks = NULL, ...)
+#' @importFrom cli cli_abort
+.create_categorized <- function(val, brks = NULL, ...)
 {
   if (is.character(val))
     val <- as.factor(val)
@@ -440,27 +408,27 @@
   if (is.factor(val)) {
     
     if (length(levels(val)) >= 10L)
-      abort("Too many categories")
+      cli_abort("Too many categories")
     
     return(val)
   }
   
   if (!is.numeric(val)) {
     msg <- paste(sQuote(typeof(val)), "is not a supported type")
-    abort(msg)
+    cli_abort(msg)
   }
   
   if (is.null(brks))
-    abort(paste("Breaks were not provided for the", 
+    cli_abort(paste("Breaks were not provided for the", 
                 "categorization of a numeric type"))
   
   rr <- range(val)
   
-  if (is_scalar_integer(brks))
+  if (rlang::is_scalar_integer(brks))
     brks <- seq(rr[1], rr[2], diff(rr) / brks)
   
   if (rr[1] < min(brks) || rr[2] > max(brks))
-    abort("Values are out of range of breaks")
+    cli_abort("Values are out of range of breaks")
   
   cut(val, brks, include.lowest = TRUE)
 }
@@ -470,13 +438,9 @@
 
 
 
-
-#' @importFrom RColorBrewer brewer.pal
 #' @importFrom RColorBrewer brewer.pal.info
-#' @importFrom magrittr %>%
-#' @importFrom rlang abort
-#' @importFrom tools toTitleCase
-.processColouring <- function(col = NULL, n, ...)
+#' @importFrom cli cli_abort
+.process_colouring <- function(col = NULL, n, ...)
 {
   .DefaultChoroplethColours <- getOption('choropleth.colours') # set in zzz.R
   
@@ -485,13 +449,11 @@
   
   if (is.numeric(col)) {
     default.pal <- .get_R_palette()
-    all.cols <- default.pal %>% 
-      sub("(green)(3)", "\\1", .) %>% 
-      sub("gray", "grey", .)
+    all.cols <- sub("(green)(3)", "\\1", default.pal)
+    all.cols <- sub("gray", "grey", all.cols)
     
     if (!col %in% seq_along(all.cols))
-      abort(sprintf("'color' must range between 1L and %iL", 
-                    length(all.cols)))
+      cli_abort("'color' must range between 1L and {length(all.cols)}L")
     
     col <- all.cols[col]
   }
@@ -499,16 +461,12 @@
   among.def.cols <- col %in% .DefaultChoroplethColours
   in.other.pal <- !among.def.cols && (col %in% rownames(brewer.pal.info))
   
-  pal <-
-    if (!among.def.cols) {
-      
-      if (!in.other.pal)
-        abort(
-          sprintf("'%s' is not a supported colour or palette", col)
-        )
-      
-      col
-    }
+  pal <- if (!among.def.cols) {
+    if (!in.other.pal)
+      cli_abort("'{col}' is not a supported colour or palette")
+    
+    col
+  }
   else
     paste0(tools::toTitleCase(col), "s")
   
@@ -518,14 +476,12 @@
 
 
 
-
-
-
 #' @importFrom grDevices palette
 .get_R_palette <- function()
 {
   if (getRversion() < as.numeric_version('4.0.0'))
     return(palette())
+  
   palette('R3')
   pp <- palette()
   palette('R4')
@@ -535,14 +491,12 @@
 
 
 
-
-
-
 # Reassigns colours to polygons that refer to similar regions i.e. duplicated
 # polygon, ensuring that when the choropleth is drawn, the colours are 
 # properly applied to the respective regions and not recycled.
+#' @importFrom cli cli_abort
 #' @importFrom grDevices colours
-.reassignColours <- 
+.reassign_colours <- 
   function(names, all.regions, in.colours, excl.region = NULL, excl.col = NULL)
   {
     stopifnot({
@@ -554,7 +508,7 @@
     out.colours <- new.names <- rep(NA, length(names))
     
     for (i in seq_along(all.regions)) {
-      regx <- .regexDuplicatedPolygons(all.regions[i])
+      regx <- .regex_duplicated_poly(all.regions[i])
       ind <- grep(regx, names)
       out.colours[ind] <- in.colours[i]
       new.names[ind] <- sub(regx, "\\1", names[ind])[1]
@@ -568,16 +522,16 @@
       if (!is.null(excl.col)) {
         
         if (length(excl.col) > 1L)
-          stop(paste("Only one colour can be used to denote regions excluded",
-                     "from the choropleth colouring scheme"))
+          cli_abort("Only one colour can be used to denote regions excluded
+                     from the choropleth colouring scheme")
         
         if (!is.character(excl.col))
-          stop(sprintf("Colour indicators of type '%s' are not supported",
-                       typeof(excl.col)))
+          cli_abort("Colour indicators of type '{typeof(excl.col)}'
+                    are not supported")
         
         if (!excl.col %in% colours())
-          stop(paste("The colour used for excluded regions must be valid",
-                     "i.e. an element of the built-in set 'colours()'"))
+          cli_abort("The colour used for excluded regions must be valid
+                     i.e. an element of the built-in set 'colours()'")
         
         off.color <- excl.col
       }
@@ -596,7 +550,7 @@
 
 # Provides a regex pattern for checking polygons for jurisdictions that
 # are matched more than once e.g. foo:1, foo:2, bar:1, bar:2, bar:3
-.regexDuplicatedPolygons <- function(x)
+.regex_duplicated_poly <- function(x)
 {
   stopifnot(is.character(x))
   paste0("^(", paste0(x, collapse = "|"),")(\\:\\d)?$")
@@ -605,7 +559,7 @@
 
 
 
-.regexSubsetRegions <- function(x) {
+.regex_subset_regions <- function(x) {
   stopifnot(is.character(x))
   paste0(x, collapse = "|")
 }
@@ -627,8 +581,7 @@
 
 # Rejigs text that is used for labeling a region that has more than 1 polygon
 # TODO: Quite a bit of hard-coding was used (v. 0.1.0) and should be reviewed
-#' @importFrom magrittr %>%
-.adjustLabels <- function(x) 
+.adjust_labels <- function(x) 
 {
   stopifnot(is.character(x))
   x <- vapply(
@@ -638,12 +591,12 @@
       sub("\\:\\d*$", "", l)
   )
   
-  
   dd <- data.frame(state = c("Akwa Ibom", "Cross River"),
                    poly = c(2, 4))
+  
   ss <- dd[["state"]]
+  
   if (all(grepl(paste0(ss, collapse = "|"), x))) {
-    
     .fadj <- function(a, reg, pos) {
       ind <- grep(reg, a)
       finalPos <- ind[pos]
@@ -651,6 +604,7 @@
       a[finalPos] <- reg
       a
     }
+    
     for (i in seq_len(2))
       x <- .fadj(x, ss[i], dd[["poly"]][i])
   }
@@ -668,9 +622,10 @@
 # Note: This check is probably too expensive. Consider passing just the range
 # though the loss of typing may make this less reliable down the line
 #' @importFrom rlang is_double
-.xyWithinBounds <- function(map, x, y)
+.xy_within_bounds <- function(map, x, y)
 { 
   stopifnot(inherits(map, 'map'), is_double(x), is_double(y))
+  
   rr <- map$range
   xx <- x >= rr[1] & x <= rr[2]
   yy <- y >= rr[3] & y <= rr[4]
@@ -686,8 +641,7 @@
 ## Then, read the shapefile
 ## Collect the namefield from the data, based on the region
 #' @importFrom methods slot
-#' @importFrom rgdal readOGR
-ShapefileProps <- function(regions)
+shpfile_props <- function(regions)
 {
   shp <- .getShapefileDir(regions)
   pkgdir <- "extdata"
@@ -697,12 +651,12 @@ ShapefileProps <- function(regions)
                      mustWork = TRUE)
   
   if (identical(dsn, character(1)))
-    stop(sprintf("The map data could not be found in '%s'", pkgdir))
+    cli::cli_abort("The map data could not be found in '{pkgdir}'")
   
   rgx <- "\\.shp$"
   shpfl <- list.files(dsn, rgx)
   lyr <- sub(pattern = paste0("(.+)(", rgx, ")"), "\\1", shpfl)
-  sp <- readOGR(dsn, lyr, verbose = FALSE)
+  sp <- rgdal::readOGR(dsn, lyr, verbose = FALSE)
   
   ## The following shapefile, has some unwanted data
   if (shp == "nigeria-lgas") 
@@ -713,20 +667,20 @@ ShapefileProps <- function(regions)
   if (shp == "nigeria-lgas")
     dt$STATE[dt$STATE == "Abuja"] <- "Federal Capital Territory"
   
-  nmfld <- .fetchNamefield(regions, dt)
+  nmfld <- .fetch_namefield(regions, dt)
   stopifnot(!is.na(nmfld))
-  new_ShapefileProps(shp, lyr, nmfld, sp)
+  new_shpfile_props(shp, lyr, nmfld, sp)
 }
 
 
 
 
 ## Low-level constructor
-new_ShapefileProps <- function(dir, layer, namefield, spObj)
+new_shpfile_props <- function(dir, layer, namefield, spObj)
 {
   structure(list(dir, layer, namefield, spObj),
             names = c("shapefile", "layer", "namefield", "spatialObject"), 
-            class = "ShapefileProps")
+            class = "shpfile_props")
 }
 
 
@@ -735,58 +689,44 @@ new_ShapefileProps <- function(dir, layer, namefield, spObj)
 
 
 ## Fetch the namefield
-## This is a generic function. The methods we have are for distinguishing
-## how namefields are retrieved, since this varies depending on the kind 
-## of region passed. The interesting case in point is when getting this 
-## field for LGA regions, since the spatial data also contains data on 
-## States. To avoid confusion, when iterating through the data frame, when
-## a column with States is encountered it is skipped as can be seen in the
-## `.fetchNamefield.lgas` method.
-.fetchNamefield <- function(x, ...)
-  UseMethod(".fetchNamefield")
-
-
-.fetchNamefield.lgas <- function(x, dt) {
-  nmfld <- NA
+.fetch_namefield <- function(x, dt) {
+  getfield <- function(index) names(dt)[[index]]
+  stopifnot(is.data.frame(dt))
+  nmfield <- NA
   
   for (i in seq_len(ncol(dt))) {
+    icolumn <- dt[[i]]
+    iregions <- x %in% icolumn
     
-    if (all(unique(dt[[i]]) %in% states()))  # skip column with States
-      next
-    
-    if (any(x %in% dt[[i]])) {   # just any LGAs will do, since some of them
-      nmfld <- colnames(dt)[i]   # also share names with their State
-      break
-    }
-  }
-  
-  nmfld
-}
-
-
-
-
-.fetchNamefield.states <- function(x, dt) {
-  # dt[[1]][dt[[1]] == "Nasarawa"] <- "Nassarawa" # Fix for 'ng_admin'
-  nmfld <- NA
-  
-  for (i in seq_len(ncol(dt))) {
-    
-    if (all(x %in% dt[[i]])) {   # all MUST be states
-      nmfld <- colnames(dt)[i]
+    if (inherits(x, "states") && all(iregions)) {
+      nmfield <- getfield(i)
       break
     }
     
+    if (inherits(x, "lgas")) {
+      # skip datafrane column with States
+      if (all(unique(icolumn) %in% states()))
+        next
+      
+      # just any LGAs will do, as some are synonymous with States
+      if (any(iregions)) {
+        nmfield <- getfield(i)
+        break
+      }
+    }
   }
   
-  nmfld
+  if (is.null(nmfield) || is.na(nmfield))
+    cli::cli_abort("Problem retrieving the namefield")
+  
+  nmfield
 }
 
 
 
 
 # Returns either a logical(1) or character(n)
-.setLegendText <- function(val)
+.set_legend_text <- function(val)
 {
   arg <- "legend.text"
   
@@ -796,7 +736,7 @@ new_ShapefileProps <- function(dir, layer, namefield, spObj)
   
   if (is.logical(val)) {
     if (length(val) > 1L)
-      warning(.first_elem_warn(arg))
+      cli::cli_warn(.first_elem_warn(arg))
     
     return(val[1])
   }
@@ -804,16 +744,16 @@ new_ShapefileProps <- function(dir, layer, namefield, spObj)
   if (is.character(val))
     return(val)
   
-  stop(sprintf("'%s' must be of type character or logical", arg))
+  cli::cli_abort("'{arg}' must be of type character or logical")
 }
 
 
 
 
 
-.setLegendParams <- function(leg.arg)
+.set_legend_params <- function(leg.arg)
 {
-  result <- .setLegendText(leg.arg)
+  result <- .set_legend_text(leg.arg)
   obj <- list(x = 13L, y = 7L, text = NULL, show = TRUE, xpd = NA)
   
   if (is.character(result))
@@ -829,12 +769,13 @@ new_ShapefileProps <- function(dir, layer, namefield, spObj)
 
 
 
-.setTextSize <- function(cex = NULL)
+.set_text_size <- function(cex = NULL)
 {
   if (is.null(cex)) {
     cex <- 0.75  # default for maps::map.text
     return(cex)
   }
+  
   stopifnot(is.numeric(cex))
   cex
 }
@@ -844,17 +785,22 @@ new_ShapefileProps <- function(dir, layer, namefield, spObj)
 
 
 ## Messages -----------------------------------------------------------------
-.ngName <- function()
+country_name <- function()
 {
   "Nigeria"
 }
 
+
+
+
 .arg_str <- function(arg)
 {
   deparse(substitute(arg))
 }
 
 
+
+
 .first_elem_warn <- function(arg)
 {
   stopifnot(is.character(arg) && length(arg) == 1L)
@@ -862,12 +808,16 @@ new_ShapefileProps <- function(dir, layer, namefield, spObj)
 }
 
 
-.nextMinorVer <- function()
+
+
+.next_minor_version <- function()
 {
   ">= 0.6.0"
 }
 
 
-.deprecMsg <- function(arg) {
+
+
+.deprec_msg <- function(arg) {
   sprintf("map_ng(%s = )", deparse(substitute(arg)))
 }
